@@ -1,5 +1,4 @@
 import keyword
-import logging
 import dataclasses
 from collections import defaultdict
 
@@ -138,7 +137,7 @@ def test_commands_schema():
 
                     commands_by_id[cmd.Req.header].append(cmd.Req)
                 else:
-                    assert False, "Command is empty"
+                    assert False, "Command is empty"  # noqa: B011
             elif cmd.type == t.CommandType.SRSP:
                 # The one command like this is RPCError
                 assert cmd is c.RPCError.CommandNotRecognized
@@ -154,7 +153,7 @@ def test_commands_schema():
 
                 commands_by_id[cmd.Rsp.header].append(cmd.Rsp)
             else:
-                assert False, "Command has unknown type"
+                assert False, "Command has unknown type"  # noqa: B011
 
     duplicate_commands = {
         cmd: commands for cmd, commands in commands_by_id.items() if len(commands) > 1
@@ -173,11 +172,11 @@ def test_command_param_binding():
         c.SYS.Ping.Rsp(asd=123)
 
     # Valid param name
-    c.SYS.Ping.Rsp(Capabilities=t.MTCapabilities.CAP_SYS)
+    c.SYS.Ping.Rsp(Capabilities=t.MTCapabilities.SYS)
 
     # Too many params, one valid
     with pytest.raises(KeyError):
-        c.SYS.Ping.Rsp(foo="asd", Capabilities=t.MTCapabilities.CAP_SYS)
+        c.SYS.Ping.Rsp(foo="asd", Capabilities=t.MTCapabilities.SYS)
 
     # Not enough params
     with pytest.raises(KeyError):
@@ -185,15 +184,15 @@ def test_command_param_binding():
 
     # Invalid type
     with pytest.raises(ValueError):
-        c.Util.TimeAlive.Rsp(Seconds=b"asd")
+        c.UTIL.TimeAlive.Rsp(Seconds=b"asd")
 
     # Valid type but invalid value
     with pytest.raises(ValueError):
-        c.Util.SetPreConfigKey.Req(PreConfigKey=t.KeyData([1, 2, 3]))
+        c.UTIL.SetPreConfigKey.Req(PreConfigKey=t.KeyData([1, 2, 3]))
 
     # Coerced numerical type
-    a = c.Util.TimeAlive.Rsp(Seconds=12)
-    b = c.Util.TimeAlive.Rsp(Seconds=t.uint32_t(12))
+    a = c.UTIL.TimeAlive.Rsp(Seconds=12)
+    b = c.UTIL.TimeAlive.Rsp(Seconds=t.uint32_t(12))
 
     assert a == b
     assert a.Seconds == b.Seconds
@@ -201,17 +200,17 @@ def test_command_param_binding():
 
     # Overflowing integer types
     with pytest.raises(ValueError):
-        c.Util.TimeAlive.Rsp(Seconds=10 ** 20)
+        c.UTIL.TimeAlive.Rsp(Seconds=10**20)
 
     # Integers will not be coerced to enums
-    assert t.MTCapabilities.CAP_SYS == 0x0001
+    assert t.MTCapabilities.SYS == 0x0001
 
     with pytest.raises(ValueError):
         c.SYS.Ping.Rsp(Capabilities=0x0001)
 
     # Parameters can be looked up by name
-    ping_rsp = c.SYS.Ping.Rsp(Capabilities=t.MTCapabilities.CAP_SYS)
-    assert ping_rsp.Capabilities == t.MTCapabilities.CAP_SYS
+    ping_rsp = c.SYS.Ping.Rsp(Capabilities=t.MTCapabilities.SYS)
+    assert ping_rsp.Capabilities == t.MTCapabilities.SYS
 
     # Invalid ones cannot
     with pytest.raises(AttributeError):
@@ -224,7 +223,7 @@ def test_command_param_binding():
     assert isinstance(cmd.Value, t.ShortBytes)
 
     # Lists are converted to typed LVLists
-    c.Util.BindAddEntry.Req(
+    c.UTIL.BindAddEntry.Req(
         DstAddrModeAddr=t.AddrModeAddress(mode=t.AddrMode.NWK, address=0x1234),
         DstEndpoint=0x56,
         ClusterIdList=[0x12, 0x45],
@@ -232,7 +231,7 @@ def test_command_param_binding():
 
     # Type errors within containers are also caught
     with pytest.raises(ValueError):
-        c.Util.BindAddEntry.Req(
+        c.UTIL.BindAddEntry.Req(
             DstAddrModeAddr=t.AddrModeAddress(mode=t.AddrMode.NWK, address=0x1234),
             DstEndpoint=0x56,
             ClusterIdList=[0x12, 0x457890],  # 0x457890 doesn't fit into a uint8_t
@@ -373,7 +372,7 @@ def test_simple_descriptor():
 
 
 def test_command_str_repr():
-    command = c.Util.BindAddEntry.Req(
+    command = c.UTIL.BindAddEntry.Req(
         DstAddrModeAddr=t.AddrModeAddress(mode=t.AddrMode.NWK, address=0x1234),
         DstEndpoint=0x56,
         ClusterIdList=[0x12, 0x34],
@@ -474,7 +473,7 @@ def test_command_equality():
     )
 
 
-def test_command_deserialization(caplog):
+def test_command_deserialization():
     command = c.SYS.NVWrite.Req(
         SysId=0x12, ItemId=0x3456, SubId=0x7890, Offset=0x00, Value=b"asdfoo"
     )
@@ -483,18 +482,12 @@ def test_command_deserialization(caplog):
     assert command.to_frame() == type(command).from_frame(command.to_frame()).to_frame()
 
     # Deserialization fails if there is unparsed data at the end of the frame
+    frame = command.to_frame()
+    bad_frame = dataclasses.replace(frame, data=frame.data + b"\x00")
+
     with pytest.raises(ValueError):
-        frame = command.to_frame()
-        bad_frame = dataclasses.replace(frame, data=frame.data + b"\x00")
-
         type(command).from_frame(bad_frame)
 
-    # But it does succeed with a warning if you explicitly allow it
-    with caplog.at_level(logging.WARNING):
-        type(command).from_frame(bad_frame, ignore_unparsed=True)
-
-    assert "Unparsed" in caplog.text
-
     # Deserialization fails if you attempt to deserialize the wrong frame
     with pytest.raises(ValueError):
         c.SYS.NVWrite.Req.from_frame(c.SYS.Ping.Req().to_frame())
